# reticle

[![Testing Status](https://travis-ci.org/clintval/reticle.svg?branch=master)](https://travis-ci.org/clintval/reticle)
[![codecov](https://codecov.io/gh/clintval/reticle/branch/master/graph/badge.svg)](https://codecov.io/gh/clintval/reticle)
[![Documentation Build Status](https://readthedocs.org/projects/reticle/badge/?version=latest)](https://reticle.readthedocs.io/en/latest/?badge=latest)
[![PyPi Release](https://badge.fury.io/py/reticle.svg)](https://badge.fury.io/py/reticle)
[![Python Versions](https://img.shields.io/pypi/pyversions/reticle.svg)](https://pypi.python.org/pypi/reticle/)
[![MyPy Checked](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

Analysis and plotting library for base substitution spectra and signatures.

```bash
❯ pip install reticle
```

Features:

- Submit Batch jobs

Read the documentation at: [reticle.readthedocs.io](https://reticle.readthedocs.io/en/latest/)

